@@ -1,4 +1,7 @@
 #!/usr/bin/env python
+
+from __future__ import print_function
+
 import unittest, os, sys
 
 # Catch silly mistakes...
@@ -34,9 +37,9 @@ a = unittest.TextTestRunner(verbosity=2).run(alltests)
 if coverage:
 	coverage.stop()
 else:
-	print "Coverage module not found. Skipping coverage report."
+	print("Coverage module not found. Skipping coverage report.")
 
-print "\nResult", a
+print("\nResult", a)
 if not a.wasSuccessful():
 	sys.exit(1)
 
