@@ -4,8 +4,9 @@ import sys
 import unittest
 
 sys.path.insert(0, '..')
-from zeroinstall.injector import autopolicy, reader, model
-from zeroinstall.injector.iface_cache import iface_cache
+from zeroinstall.support import tasks
+from zeroinstall.injector import model
+from zeroinstall.injector.policy import Policy
 
 import warnings
 import logging
@@ -14,25 +15,26 @@ logger = logging.getLogger()
 
 class TestPolicy(BaseTest):
 	def testSource(self):
-		warnings.filterwarnings("ignore", category = DeprecationWarning)
+		iface_cache = self.config.iface_cache
 
 		foo = iface_cache.get_interface('http://foo/Binary.xml')
-		reader.update(foo, 'Binary.xml')
+		self.import_feed(foo.uri, 'Binary.xml')
 		foo_src = iface_cache.get_interface('http://foo/Source.xml')
-		reader.update(foo_src, 'Source.xml')
+		self.import_feed(foo_src.uri, 'Source.xml')
 		compiler = iface_cache.get_interface('http://foo/Compiler.xml')
-		reader.update(compiler, 'Compiler.xml')
+		self.import_feed(compiler.uri, 'Compiler.xml')
 
-		p = autopolicy.AutoPolicy('http://foo/Binary.xml', dry_run = True)
-		p.freshness = 0
-		p.network_use = model.network_full
-		p.recalculate()	# Deprecated
+		self.config.freshness = 0
+		self.config.network_use = model.network_full
+		p = Policy('http://foo/Binary.xml', config = self.config)
+		tasks.wait_for_blocker(p.solve_with_downloads())
 		assert p.implementation[foo].id == 'sha1=123'
 
 		# Now ask for source instead
-		p.src = True
-		p.command = 'compile'
-		p.recalculate()
+		p.requirements.source = True
+		p.requirements.command = 'compile'
+		tasks.wait_for_blocker(p.solve_with_downloads())
+		assert p.solver.ready, p.solver.get_failure_reason()
 		assert p.implementation[foo].id == 'sha1=234'		# The source
 		assert p.implementation[compiler].id == 'sha1=345'	# A binary needed to compile it
 
