@@ -110,13 +110,13 @@ class AddBox:
 			self.window.set_response_sensitive(_RESPONSE_PREV, True)
 
 		def finish():
-			import xdgutils
+			from . import xdgutils
 			iface = iface_cache.get_interface(model.canonical_iface_uri(uri.get_text()))
 
 			try:
 				icon_path = iface_cache.get_icon_path(iface)
 				xdgutils.add_to_menu(iface, icon_path, categories[category.get_active()])
-			except SafeException, ex:
+			except SafeException as ex:
 				box = gtk.MessageDialog(self.window, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_OK, str(ex))
 				box.run()
 				box.destroy()
