@@ -18,7 +18,8 @@ _dotted_ints = '[0-9]+(?:\.[0-9]+)*'
 _zeroinstall_regexp = '(?:%s)(?:-(?:pre|rc|post|)(?:%s))*' % (_dotted_ints, _dotted_ints)
 
 # This matches the interesting bits of distribution version numbers
-_version_regexp = '(%s)(-r%s)?' % (_zeroinstall_regexp, _dotted_ints)
+# (first bit is for Java-style 6b17 syntax)
+_version_regexp = '({ints}b)?({zero})(-r{ints})?'.format(zero = _zeroinstall_regexp, ints = _dotted_ints)
 
 # We try to do updates atomically without locking, but we don't worry too much about
 # duplicate entries or being a little out of sync with the on-disk copy.
@@ -123,7 +124,9 @@ def try_cleanup_distro_version(version):
 	version = version.replace('_', '-')
 	match = re.match(_version_regexp, version)
 	if match:
-		version, revision = match.groups()
+		major, version, revision = match.groups()
+		if major is not None:
+			version = major[:-1] + '.' + version
 		if revision is None:
 			return version
 		else:
@@ -320,6 +323,7 @@ _canonical_machine = {
 	'any' : '*',
 	'noarch' : '*',
 	'(none)' : '*',
+	'x86_64': 'x86_64',
 	'amd64': 'x86_64',
 	'i386': 'i386',
 	'i486': 'i486',
@@ -395,7 +399,8 @@ class DebianDistribution(Distribution):
 					impl.machine = candidate_arch
 				def install(handler):
 					raise model.SafeException(_("This program depends on '%s', which is a package that is available through your distribution. "
-							"Please install it manually using your distribution's tools and try again.") % package)
+							"Please install it manually using your distribution's tools and try again. Or, install 'packagekit' and I can "
+							"use that to install it.") % package)
 				impl.download_sources.append(model.DistributionSource(package, cached['size'], install, needs_confirmation = False))
 
 	def get_score(self, disto_name):
@@ -590,6 +595,56 @@ class PortsDistribution(Distribution):
 	def get_score(self, disto_name):
 		return int(disto_name == 'Ports')
 
+class MacPortsDistribution(CachedDistribution):
+
+	cache_leaf = 'macports-status.cache'
+
+	def generate_cache(self):
+		cache = []
+
+#		for line in os.popen("port echo active"):
+		for line in os.popen("port -v installed"):
+			if not line.startswith(" "):
+				continue
+			if line.strip().count(" ") > 1:
+				package, version, extra = line.split(None, 2)
+			else:
+				package, version = line.split()
+				extra = ""
+			if not extra.startswith("(active)"):
+				continue
+			version = version.lstrip('@')
+			version = re.sub(r"\+.*","",version) # strip variants
+			zi_arch = '*'
+			clean_version = try_cleanup_distro_version(version)
+			if clean_version:
+				match = re.match(r" platform='([^' ]*)( \d+)?' archs='([^']*)'", extra)
+				if match:
+					platform, major, archs = match.groups()
+					for arch in archs.split():
+						zi_arch = canonical_machine(arch)
+						cache.append('%s\t%s\t%s' % (package, clean_version, zi_arch))
+				else:
+					cache.append('%s\t%s\t%s' % (package, clean_version, zi_arch))
+			else:
+				warn(_("Can't parse distribution version '%(version)s' for package '%(package)s'"), {'version': version, 'package': package})
+
+		self._write_cache(cache)
+
+	def get_package_info(self, package, factory):
+		# Add installed versions...
+		versions = self.versions.get(package, [])
+
+		for version, machine in versions:
+			impl = factory('package:macports:%s:%s:%s' % (package, version, machine))
+			impl.version = model.parse_version(version)
+			if machine != '*':
+			    impl.machine = machine
+
+	def get_score(self, disto_name):
+		return int(disto_name == 'MacPorts')
+
+
 _host_distribution = None
 def get_host_distribution():
 	"""Get a Distribution suitable for the host operating system.
@@ -602,12 +657,15 @@ def get_host_distribution():
 		_rpm_db = '/var/lib/rpm/Packages'
 		_slack_db = '/var/log/packages'
 		_pkg_db = '/var/db/pkg'
+		_macports_db = '/opt/local/var/macports/registry/registry.db'
 
 		if os.path.isdir(_pkg_db):
 			if sys.platform.startswith("linux"):
 				_host_distribution = GentooDistribution(_pkg_db)
 			elif sys.platform.startswith("freebsd"):
 				_host_distribution = PortsDistribution(_pkg_db)
+		elif os.path.isfile(_macports_db):
+			_host_distribution = MacPortsDistribution(_macports_db)
 		elif os.access(dpkg_db_status, os.R_OK):
 			_host_distribution = DebianDistribution(dpkg_db_status, pkgcache)
 		elif os.path.isfile(_rpm_db):
