@@ -518,7 +518,7 @@ class DistributionSource(RetrievalMethod):
 class Command(object):
 	"""A Command is a way of running an Implementation as a program."""
 
-	__slots__ = ['qdom', '_depends', '_local_dir', '_runner']
+	__slots__ = ['qdom', '_depends', '_local_dir', '_runner', '_bindings']
 
 	def __init__(self, qdom, local_dir):
 		"""@param qdom: the <command> element
@@ -528,6 +528,7 @@ class Command(object):
 		self.qdom = qdom
 		self._local_dir = local_dir
 		self._depends = None
+		self._bindings = None
 
 	path = property(lambda self: self.qdom.attrs.get("path", None))
 
@@ -559,6 +560,18 @@ class Command(object):
 	def __str__(self):
 		return str(self.qdom)
 
+	@property
+	def bindings(self):
+		"""@since: 1.3"""
+		if self._bindings is None:
+			bindings = []
+			for e in self.qdom.childNodes:
+				if e.uri != XMLNS_IFACE: continue
+				if e.name in binding_names:
+					bindings.append(process_binding(e))
+			self._bindings = bindings
+		return self._bindings
+
 class Implementation(object):
 	"""An Implementation is a package which implements an Interface.
 	@ivar download_sources: list of methods of getting this implementation
@@ -654,7 +667,7 @@ class Implementation(object):
 			if "run" in self.commands:
 				del self.commands["run"]
 		else:
-			self.commands["run"] = Command(qdom.Element(XMLNS_IFACE, 'command', {'path': path}), None)
+			self.commands["run"] = Command(qdom.Element(XMLNS_IFACE, 'command', {'path': path, 'name': 'run'}), None)
 	main = property(_get_main, _set_main)
 
 	def is_available(self, stores):
@@ -1077,7 +1090,7 @@ class ZeroInstallFeed(object):
 		root_commands = {}
 		if main:
 			info("Note: @main on document element is deprecated in %s", self)
-			root_commands['run'] = Command(qdom.Element(XMLNS_IFACE, 'command', {'path': main}), None)
+			root_commands['run'] = Command(qdom.Element(XMLNS_IFACE, 'command', {'path': main, 'name': 'run'}), None)
 		process_group(feed_element, root_attrs, [], [], root_commands)
 	
 	def get_distro_feed(self):
@@ -1209,8 +1222,7 @@ def canonical_iface_uri(uri):
 				raise alias.NotAnAliasScript("Not found in $PATH: " + alias_prog)
 		else:
 			full_path = alias_prog
-		interface_uri, main = alias.parse_script(full_path)
-		return interface_uri
+		return alias.parse_script(full_path).uri
 	else:
 		iface_uri = os.path.realpath(uri)
 		if os.path.isfile(iface_uri):
