@@ -5,7 +5,7 @@ PackageKit integration.
 # Copyright (C) 2010, Aleksey Lim
 # See the README file for details, or visit http://0install.net.
 
-import os
+import os, sys
 import locale
 import logging
 from zeroinstall import _, SafeException
@@ -23,11 +23,13 @@ except Exception as ex:
 	_logger_pk.info("D-BUS not available: %s", ex)
 	dbus = None
 
+MAX_PACKAGE_KIT_TRANSACTION_SIZE = 100
+
 class PackageKit(object):
 	def __init__(self):
 		self._pk = False
 
-		self._candidates = {}	# { package_name : (version, arch, size) | Blocker }
+		self._candidates = {}	# { package_name : [ (version, arch, size) ] | Blocker }
 
 		# PackageKit is really slow at handling separate queries, so we use this to
 		# batch them up.
@@ -58,32 +60,33 @@ class PackageKit(object):
 		@param factory: a function to add a new implementation to the feed
 		@param prefix: the prefix for the implementation's ID
 		"""
-		candidate = self._candidates.get(package_name, None)
-		if candidate is None:
+		candidates = self._candidates.get(package_name, None)
+		if candidates is None:
 			return
 
-		if isinstance(candidate, tasks.Blocker):
+		if isinstance(candidates, tasks.Blocker):
 			return		# Fetch still in progress
 
-		impl_name = '%s:%s:%s:%s' % (prefix, package_name, candidate['version'], candidate['arch'])
+		for candidate in candidates:
+			impl_name = '%s:%s:%s:%s' % (prefix, package_name, candidate['version'], candidate['arch'])
 
-		impl = factory(impl_name, only_if_missing = True, installed = candidate['installed'])
-		if impl is None:
-			# (checking this way because the cached candidate['installed'] may be stale)
-			return		# Already installed
+			impl = factory(impl_name, only_if_missing = True, installed = candidate['installed'])
+			if impl is None:
+				# (checking this way because the cached candidate['installed'] may be stale)
+				return		# Already installed
 
-		impl.version = model.parse_version(candidate['version'])
-		if candidate['arch'] != '*':
-			impl.machine = candidate['arch']
+			impl.version = model.parse_version(candidate['version'])
+			if candidate['arch'] != '*':
+				impl.machine = candidate['arch']
 
-		def install(handler):
-			packagekit_id = candidate['packagekit_id']
-			def download_factory(url, hint):
-				return PackageKitDownload(url, hint, pk = self.pk, packagekit_id = packagekit_id)
-			dl = handler.get_download('packagekit:' + packagekit_id, factory = download_factory, hint = impl)
-			dl.expected_size = candidate['size']
-			return dl.downloaded
-		impl.download_sources.append(model.DistributionSource(package_name, candidate['size'], install))
+			def install(handler):
+				packagekit_id = candidate['packagekit_id']
+				def download_factory(url, hint):
+					return PackageKitDownload(url, hint, pk = self.pk, packagekit_id = packagekit_id)
+				dl = handler.get_download('packagekit:' + packagekit_id, factory = download_factory, hint = impl)
+				dl.expected_size = candidate['size']
+				return dl.downloaded
+			impl.download_sources.append(model.DistributionSource(package_name, candidate['size'], install))
 
 	@tasks.async
 	def fetch_candidates(self, package_names):
@@ -106,7 +109,8 @@ class PackageKit(object):
 		# Filter out the ones we've already fetched
 		package_names = [p for p in package_names if p not in self._candidates]
 
-		if package_names:
+		def do_batch(package_names):
+			#_logger_pk.info("sending %d packages in batch", len(package_names))
 			versions = {}
 
 			blocker = None
@@ -121,14 +125,23 @@ class PackageKit(object):
 					if packagekit_id in sender.details:
 						info.update(sender.details[packagekit_id])
 						info['packagekit_id'] = packagekit_id
-						self._candidates[info['name']] = info
+						if (info['name'] not in self._candidates or
+						    isinstance(self._candidates[info['name']], tasks.Blocker)):
+							self._candidates[info['name']] = [info]
+						else:
+							self._candidates[info['name']].append(info)
 					else:
 						_logger_pk.info(_('Empty details for %s'), packagekit_id)
 				blocker.trigger()
 
 			def resolve_cb(sender):
 				if sender.package:
-					versions.update(sender.package)
+					for packagekit_id, info in sender.package.iteritems():
+						parts = packagekit_id.split(';', 3)
+						if ':' in parts[3]:
+							parts[3] = parts[3].split(':', 1)[0]
+							packagekit_id = ';'.join(parts)
+						versions[packagekit_id] = info
 					tran = _PackageKitTransaction(self.pk, details_cb, error_cb)
 					tran.proxy.GetDetails(versions.keys())
 				else:
@@ -140,19 +153,39 @@ class PackageKit(object):
 			for package in package_names:
 				self._candidates[package] = blocker
 
-			_logger_pk.debug(_('Ask for %s'), package_names)
-			tran = _PackageKitTransaction(self.pk, resolve_cb, error_cb)
-			tran.proxy.Resolve('none', package_names)
+			try:
+				_logger_pk.debug(_('Ask for %s'), package_names)
+				tran = _PackageKitTransaction(self.pk, resolve_cb, error_cb)
+				tran.proxy.Resolve('none', package_names)
 
-			in_progress.append(blocker)
+				in_progress.append(blocker)
+			except:
+				__, ex, tb = sys.exc_info()
+				blocker.trigger((ex, tb))
+				raise
+
+		# Now we've collected all the requests together, split them up into chunks
+		# that PackageKit can handle ( < 100 per batch )
+		#_logger_pk.info("sending %d packages", len(package_names))
+		while package_names:
+			next_batch = package_names[:MAX_PACKAGE_KIT_TRANSACTION_SIZE]
+			package_names = package_names[MAX_PACKAGE_KIT_TRANSACTION_SIZE:]
+			do_batch(next_batch)
 
 		while in_progress:
 			yield in_progress
 			in_progress = [b for b in in_progress if not b.happened]
 
-class PackageKitDownload(download.Download):
+class PackageKitDownload:
 	def __init__(self, url, hint, pk, packagekit_id):
-		download.Download.__init__(self, url, hint)
+		self.url = url
+		self.status = download.download_starting
+		self.hint = hint
+		self.aborted_by_user = False
+
+		self.downloaded = None
+
+		self.expected_size = None	# Final size (excluding skipped bytes)
 
 		self.packagekit_id = packagekit_id
 		self._impl = hint
