@@ -119,8 +119,8 @@ class SATSolver(Solver):
 
 	def set_langs(self, langs):
 		"""Set the preferred languages.
-		@param lang: languages (and regions), first choice first
-		@type lang: [str]
+		@param langs: languages (and regions), first choice first
+		@type langs: [str]
 		"""
 		# _lang_ranks is a map from locale string to score (higher is better)
 		_lang_ranks = {}
@@ -644,14 +644,22 @@ class SATSolver(Solver):
 
 			commands_needed = []
 
+			# Popular sels with the selected implementations.
+			# Also, note down all the commands we need.
 			for uri, group in group_clause_for.iteritems():
 				if group.current is not None:
 					lit_info = problem.get_varinfo_for_lit(group.current).obj
 					if lit_info.is_dummy:
 						sels[lit_info.iface.uri] = None
 					else:
+						# We selected an implementation for interface 'uri'
 						impl = lit_info.impl
 
+						for b in impl.bindings:
+							c = b.command
+							if c is not None:
+								commands.append((uri, c))
+
 						deps = self.requires[lit_info.iface] = []
 						for dep in deps_in_use(lit_info.impl, lit_info.arch):
 							deps.append(dep)
@@ -660,14 +668,25 @@ class SATSolver(Solver):
 	
 						sels[lit_info.iface.uri] = selections.ImplSelection(lit_info.iface.uri, impl, deps)
 
+			# Now all all the commands in too.
 			def add_command(iface, name):
 				sel = sels.get(iface, None)
 				if sel:
 					command = sel.impl.commands[name]
+					if name in sel._used_commands:
+						return	# Already added
 					sel._used_commands.add(name)
-					runner = command.get_runner()
-					if runner:
-						add_command(runner.metadata['interface'], runner.command)
+
+					for dep in command.requires:
+						for dep_command_name in dep.get_required_commands():
+							add_command(dep.interface, dep_command_name)
+
+					# A <command> can depend on another <command> in the same interface
+					# (e.g. the tests depending on the main program)
+					for b in command.bindings:
+						c = b.command
+						if c is not None:
+							add_command(iface, c)
 
 			for iface, command in commands_needed:
 				add_command(iface, command)
