@@ -78,9 +78,9 @@ def ro_rmtree(root):
 	if platform.system() == 'Windows':
 		for main, dirs, files in os.walk(root):
 			for i in files + dirs:
-				os.chmod(os.path.join(main, i), 0700)
-		os.chmod(root, 0700)
+				os.chmod(os.path.join(main, i), 0o700)
+		os.chmod(root, 0o700)
 	else:
 		for main, dirs, files in os.walk(root):
-			os.chmod(main, 0700)
+			os.chmod(main, 0o700)
 	shutil.rmtree(root)
